// SPDX-License-Identifier: GPL-2.0
#ifndef WORLDMAP_SAVE_H
#define WORLDMAP_SAVE_H

#ifdef __cplusplus
extern "C" {
#endif

extern void export_worldmap_HTML(const char *file_name, bool selected_only);

#ifdef __cplusplus
}
#endif

#endif
